@@ -526,7 +526,7 @@ void paranoia_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry,
     sj_extractor_set_paranoia (extractor, DEFAULT_PARANOIA);
   } else {
     int value = gconf_value_get_int (entry->value);
-    if (value == 0 || value == 4 || value == 255) {
+    if (value == 0 || value == 2 || value == 4 || value == 8 || value == 16 || value == 255) {
       sj_extractor_set_paranoia (extractor, value);
     }
   }
@@ -1009,7 +1009,9 @@ static void on_extract_toggled (GtkCellRendererToggle *cellrenderertoggle,
 {
   gboolean extract;
   GtkTreeIter iter;
-  gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (track_store), &iter, path);
+
+  if (!gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (track_store), &iter, path))
+      return;
   gtk_tree_model_get (GTK_TREE_MODEL (track_store), &iter, COLUMN_EXTRACT, &extract, -1);
   /* extract is the old state here, so toggle */
   extract = !extract;
@@ -1054,7 +1056,9 @@ static void on_cell_edited (GtkCellRendererText *renderer,
   GtkTreeIter iter;
   TrackDetails *track;
   char *artist, *title;
-  gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (track_store), &iter, path);
+
+  if (!gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (track_store), &iter, path))
+    return;
   gtk_tree_model_get (GTK_TREE_MODEL (track_store), &iter,
                       COLUMN_ARTIST, &artist,
                       COLUMN_TITLE, &title,
@@ -1215,6 +1219,7 @@ on_message_received (const char *message, gpointer user_data)
 
 int main (int argc, char **argv)
 {
+  GnomeProgram *program;
   GError *error = NULL;
   GtkTreeSelection *selection;
   char *device = NULL;
@@ -1230,20 +1235,20 @@ int main (int argc, char **argv)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  g_set_application_name (_("Sound Juicer"));
-  
   ctx = g_option_context_new ("- Sound Juicer");
   g_option_context_add_main_entries (ctx, entries, GETTEXT_PACKAGE);  
   g_option_context_add_group (ctx, gst_init_get_option_group ());
   g_option_context_set_ignore_unknown_options (ctx, TRUE);
 
-  gnome_program_init ("sound-juicer", 	 
+  program = gnome_program_init ("sound-juicer", 	 
                       VERSION, LIBGNOMEUI_MODULE, 	 
                       argc, argv, 	 
                       GNOME_PROGRAM_STANDARD_PROPERTIES,
                       GNOME_PARAM_GOPTION_CONTEXT, ctx,
                       NULL);
 
+  g_set_application_name (_("Sound Juicer"));
+
   sj_stock_init ();
 
   gtk_window_set_default_icon_name ("sound-juicer");
@@ -1321,6 +1326,27 @@ int main (int argc, char **argv)
   prev_menuitem = glade_xml_get_widget (glade, "previous_track_menuitem");
   status_bar = glade_xml_get_widget (glade, "status_bar");
 
+  { /* ensure that the play/pause button's size is constant */
+    GtkWidget *fake_button1, *fake_button2;
+    GtkSizeGroup *size_group;
+
+    size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+
+    fake_button1 = gtk_button_new_from_stock (GTK_STOCK_MEDIA_PLAY);
+    gtk_size_group_add_widget (size_group, fake_button1);
+    g_signal_connect_swapped (play_button, "destroy",
+		    	      G_CALLBACK (gtk_widget_destroy),
+			      fake_button1);
+
+    fake_button2 = gtk_button_new_from_stock (GTK_STOCK_MEDIA_PAUSE);
+    gtk_size_group_add_widget (size_group, fake_button2);
+    g_signal_connect_swapped (play_button, "destroy",
+		    	      G_CALLBACK (gtk_widget_destroy),
+			      fake_button2);
+
+    gtk_size_group_add_widget (size_group, play_button);
+  }
+
   {
     GtkEntryCompletion *completion;
     completion = gtk_entry_completion_new ();
@@ -1342,7 +1368,7 @@ int main (int argc, char **argv)
                                                        toggle_renderer,
                                                        "active", COLUMN_EXTRACT,
                                                        NULL);
-    gtk_tree_view_column_set_resizable (column, TRUE);
+    gtk_tree_view_column_set_resizable (column, FALSE);
     gtk_tree_view_append_column (GTK_TREE_VIEW (track_listview), column);
 
     column = gtk_tree_view_column_new ();
@@ -1384,7 +1410,7 @@ int main (int argc, char **argv)
     column = gtk_tree_view_column_new_with_attributes (_("Duration"),
                                                        renderer,
                                                        NULL);
-    gtk_tree_view_column_set_resizable (column, TRUE);
+    gtk_tree_view_column_set_resizable (column, FALSE);
     gtk_tree_view_column_set_cell_data_func (column, renderer, duration_cell_data_cb, NULL, NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (track_listview), column);
   }
@@ -1397,11 +1423,15 @@ int main (int argc, char **argv)
   }
 
   update_ui_for_album (NULL);
-  gconf_bridge_bind_window_size(gconf_bridge_get(), GCONF_WINDOW, GTK_WINDOW (main_window));
-  gtk_widget_show (main_window);
 
   sj_play_init ();
 
+#if HAVE_TAGLIB
+  /* See if the system supports id3mux, and if not register our own */
+  if (!gst_default_registry_check_feature_version ("id3mux", 0, 10, 0))
+    id3mux_register ();
+#endif
+
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (track_listview));
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 
@@ -1424,9 +1454,13 @@ int main (int argc, char **argv)
     return 0;
   }
 
+  gconf_bridge_bind_window_size(gconf_bridge_get(), GCONF_WINDOW, GTK_WINDOW (main_window));
+  gtk_widget_show (main_window);
   gtk_main ();
+
   g_object_unref (metadata);
   g_object_unref (extractor);
   g_object_unref (gconf_client);
+  g_object_unref (program);
   return 0;
 }
